require 'dldinternet/opensrs/api/domain'

module DLDInternet
  module OpenSRS
    module Domain
      module Get
        class Command < DLDInternet::Thor::Command
          no_commands do

            require 'dldinternet/opensrs/domain/get/mixins/no_commands'
            include DLDInternet::OpenSRS::Domain::Get::MixIns::NoCommands

          end

          desc 'all_info', 'all domain info'
          def all_info(domain)
            command_pre(domain)

            answer = DLDInternet::OpenSRS::API::Domain::Get.new(options, @logger).GetAllInfo(domain)
            case @config[:format].to_s
            when /none|text/
              @config[:format] = :awesome
            end
            command_out answer
            0
          end

          desc 'list', 'list domains'
          def list()
            command_pre()
            @header = ->{ sprintf("%-48s", 'Domainname') }
            @format = ->(res) { sprintf("%-48s", res ) }

            answer = DLDInternet::OpenSRS::API::Domain::Get.new(options, @logger).GetDomainList
            command_out answer
            0
          end

          desc 'nameservers DOMAIN', 'domain dns'
          def nameservers(domain)
            dns(domain)
          end

          desc 'dns DOMAIN', 'domain dns'
          def dns(domain)
            command_pre(domain)
            @header = ->{ sprintf("%-10s\t%-48s", 'Nameserver','Hostname') }
            @format = ->(res) { sprintf("%-10s\t%-48s", res['sortorder'], res['name'] ) }

            answer = DLDInternet::OpenSRS::API::Domain::Get.new(options, @logger).GetDomainNameservers(domain).sort_by { |ns| ns['sortorder'].to_i }
            case @config[:format].to_s
            when /text|none/
              @header = ->{ sprintf("#{domain}\n%-10s\t%-48s", 'Nameserver','Hostname') }
              # output domain
              # output answer.sort_by { |ns| ns['sortorder'].to_i }.each { |ns| write "nameserver #{ns['sortorder']}: #{ns['name']}" }
            # else
            #   output answer
            end
            command_out answer
            0
          end

          desc 'status DOMAIN', 'domain status'
          def status(domain)
            command_pre domain
            @header = ->{ sprintf("%-10s\t%-10s\t%-14s", 'Lock state','Can modify','Domain supports') }
            @format = ->(res) { sprintf("%-10s\t%-10s\t%-14s", res['lock_state'], res['can_modify'], res['domain_supports'] ) }

            answer = DLDInternet::OpenSRS::API::Domain::Get.new(options, @logger).GetDomainStatus(domain)
            case @config[:format].to_s
            when /text|none/
              @header = ->{ sprintf("#{domain}\n%-10s\t%-10s\t%-14s", 'Lock state','Can modify','Domain supports') }
              # write domain
              # answer.each { |k,v| write "#{k}: #{v}" }
            # else
            #   output answer
            end
            command_out answer
            0
          end
        end
      end
    end
  end
end